.. all-saltext.kubernetes.modules:

_________________
Execution Modules
_________________

.. currentmodule:: saltext.kubernetes.modules

.. autosummary::
    :toctree:

    k8s
    kubeadm
    kubernetesmod
